Class: Weft::AccountApi
- Inherits:
-
Object
- Object
- Weft::AccountApi
- Defined in:
- lib/weft/generated/api/account_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_me(opts = {}) ⇒ MeResponse
Get the current credential principal Returns the seller Organization represented by an
ax_live_*resource key, or the buyer User represented by awk_*account key or OAuth access token. -
#get_me_with_http_info(opts = {}) ⇒ Array<(MeResponse, Integer, Hash)>
Get the current credential principal Returns the seller Organization represented by an `ax_live_*` resource key, or the buyer User represented by a `wk_*` account key or OAuth access token.
-
#initialize(api_client = ApiClient.default) ⇒ AccountApi
constructor
A new instance of AccountApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AccountApi
Returns a new instance of AccountApi.
19 20 21 |
# File 'lib/weft/generated/api/account_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/weft/generated/api/account_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_me(opts = {}) ⇒ MeResponse
Get the current credential principal
Returns the seller Organization represented by an ax_live_* resource key, or the buyer User represented by a wk_* account key or OAuth access token. Branch on data.principal_type.
26 27 28 29 |
# File 'lib/weft/generated/api/account_api.rb', line 26 def get_me(opts = {}) data, _status_code, _headers = get_me_with_http_info(opts) data end |
#get_me_with_http_info(opts = {}) ⇒ Array<(MeResponse, Integer, Hash)>
Get the current credential principal Returns the seller Organization represented by an `ax_live_*` resource key, or the buyer User represented by a `wk_*` account key or OAuth access token. Branch on `data.principal_type`.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/weft/generated/api/account_api.rb', line 35 def get_me_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.get_me ...' end # resource path local_var_path = '/api/v1/me' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MeResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AccountApi.get_me", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#get_me\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |