Class: Weft::AccountBootstrapCreated
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Weft::AccountBootstrapCreated
- Defined in:
- lib/weft/generated/models/account_bootstrap_created.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#approval ⇒ Object
Returns the value of attribute approval.
-
#capabilities ⇒ Object
Returns the value of attribute capabilities.
-
#device_code ⇒ Object
Transitional response field for older CLI releases that use OAuth device exchange.
-
#expires_at ⇒ Object
Claim-window expiry.
-
#id ⇒ Object
Returns the value of attribute id.
-
#status ⇒ Object
Returns the value of attribute status.
-
#temporary_api_key ⇒ Object
Returned once.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountBootstrapCreated
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AccountBootstrapCreated
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::AccountBootstrapCreated` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::AccountBootstrapCreated`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'capabilities') if (value = attributes[:'capabilities']).is_a?(Array) self.capabilities = value end else self.capabilities = nil end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] else self.expires_at = nil end if attributes.key?(:'approval') self.approval = attributes[:'approval'] else self.approval = nil end if attributes.key?(:'temporary_api_key') self.temporary_api_key = attributes[:'temporary_api_key'] else self.temporary_api_key = nil end if attributes.key?(:'device_code') self.device_code = attributes[:'device_code'] end end |
Instance Attribute Details
#approval ⇒ Object
Returns the value of attribute approval.
27 28 29 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 27 def approval @approval end |
#capabilities ⇒ Object
Returns the value of attribute capabilities.
22 23 24 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 22 def capabilities @capabilities end |
#device_code ⇒ Object
Transitional response field for older CLI releases that use OAuth device exchange.
33 34 35 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 33 def device_code @device_code end |
#expires_at ⇒ Object
Claim-window expiry. Null after the credential is promoted.
25 26 27 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 25 def expires_at @expires_at end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 18 def id @id end |
#status ⇒ Object
Returns the value of attribute status.
20 21 22 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 20 def status @status end |
#temporary_api_key ⇒ Object
Returned once. Store as a secret; it cannot be recovered.
30 31 32 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 30 def temporary_api_key @temporary_api_key end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 58 def self.attribute_map { :'id' => :'id', :'status' => :'status', :'capabilities' => :'capabilities', :'expires_at' => :'expires_at', :'approval' => :'approval', :'temporary_api_key' => :'temporary_api_key', :'device_code' => :'device_code' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 311 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
94 95 96 97 98 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 94 def self.openapi_nullable Set.new([ :'expires_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 81 def self.openapi_types { :'id' => :'String', :'status' => :'String', :'capabilities' => :'Array<String>', :'expires_at' => :'Time', :'approval' => :'AccountBootstrapCreatedApproval', :'temporary_api_key' => :'String', :'device_code' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 284 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && status == o.status && capabilities == o.capabilities && expires_at == o.expires_at && approval == o.approval && temporary_api_key == o.temporary_api_key && device_code == o.device_code end |
#eql?(o) ⇒ Boolean
298 299 300 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 298 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
304 305 306 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 304 def hash [id, status, capabilities, expires_at, approval, temporary_api_key, device_code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end pattern = Regexp.new(/^boot_[A-Za-z0-9_-]+$/) if @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @capabilities.nil? invalid_properties.push('invalid value for "capabilities", capabilities cannot be nil.') end if @approval.nil? invalid_properties.push('invalid value for "approval", approval cannot be nil.') end if @temporary_api_key.nil? invalid_properties.push('invalid value for "temporary_api_key", temporary_api_key cannot be nil.') end pattern = Regexp.new(/^wbt_[A-Za-z0-9_-]+$/) if @temporary_api_key !~ pattern invalid_properties.push("invalid value for \"temporary_api_key\", must conform to the pattern #{pattern}.") end if !@device_code.nil? && @device_code.to_s.length < 32 invalid_properties.push('invalid value for "device_code", the character length must be greater than or equal to 32.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 333 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/weft/generated/models/account_bootstrap_created.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @id !~ Regexp.new(/^boot_[A-Za-z0-9_-]+$/) return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["pending", "claimed", "rejected", "expired", "consumed", "revoked"]) return false unless status_validator.valid?(@status) return false if @capabilities.nil? return false if @approval.nil? return false if @temporary_api_key.nil? return false if @temporary_api_key !~ Regexp.new(/^wbt_[A-Za-z0-9_-]+$/) return false if !@device_code.nil? && @device_code.to_s.length < 32 true end |