Class: Weft::Agent

Inherits:
ApiModelBase show all
Defined in:
lib/weft/generated/models/agent.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Agent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/weft/generated/models/agent.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::Agent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::Agent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  else
    self.slug = nil
  end

  if attributes.key?(:'wallet_address')
    self.wallet_address = attributes[:'wallet_address']
  else
    self.wallet_address = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  else
    self.category = nil
  end

  if attributes.key?(:'visibility')
    self.visibility = attributes[:'visibility']
  else
    self.visibility = nil
  end

  if attributes.key?(:'verified')
    self.verified = attributes[:'verified']
  else
    self.verified = nil
  end

  if attributes.key?(:'claimed')
    self.claimed = attributes[:'claimed']
  else
    self.claimed = nil
  end

  if attributes.key?(:'stats')
    self.stats = attributes[:'stats']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end
end

Instance Attribute Details

#categoryObject

Returns the value of attribute category.



28
29
30
# File 'lib/weft/generated/models/agent.rb', line 28

def category
  @category
end

#claimedObject

Whether the agent is claimed by a user



35
36
37
# File 'lib/weft/generated/models/agent.rb', line 35

def claimed
  @claimed
end

#created_atObject

Returns the value of attribute created_at.



39
40
41
# File 'lib/weft/generated/models/agent.rb', line 39

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



26
27
28
# File 'lib/weft/generated/models/agent.rb', line 26

def description
  @description
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/weft/generated/models/agent.rb', line 18

def id
  @id
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/weft/generated/models/agent.rb', line 20

def name
  @name
end

#slugObject

Returns the value of attribute slug.



22
23
24
# File 'lib/weft/generated/models/agent.rb', line 22

def slug
  @slug
end

#statsObject

Returns the value of attribute stats.



37
38
39
# File 'lib/weft/generated/models/agent.rb', line 37

def stats
  @stats
end

#verifiedObject

Returns the value of attribute verified.



32
33
34
# File 'lib/weft/generated/models/agent.rb', line 32

def verified
  @verified
end

#visibilityObject

Returns the value of attribute visibility.



30
31
32
# File 'lib/weft/generated/models/agent.rb', line 30

def visibility
  @visibility
end

#wallet_addressObject

Returns the value of attribute wallet_address.



24
25
26
# File 'lib/weft/generated/models/agent.rb', line 24

def wallet_address
  @wallet_address
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/weft/generated/models/agent.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/weft/generated/models/agent.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/weft/generated/models/agent.rb', line 64

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'slug' => :'slug',
    :'wallet_address' => :'wallet_address',
    :'description' => :'description',
    :'category' => :'category',
    :'visibility' => :'visibility',
    :'verified' => :'verified',
    :'claimed' => :'claimed',
    :'stats' => :'stats',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/weft/generated/models/agent.rb', line 379

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/weft/generated/models/agent.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/weft/generated/models/agent.rb', line 91

def self.openapi_types
  {
    :'id' => :'Integer',
    :'name' => :'String',
    :'slug' => :'String',
    :'wallet_address' => :'String',
    :'description' => :'String',
    :'category' => :'String',
    :'visibility' => :'String',
    :'verified' => :'Boolean',
    :'claimed' => :'Boolean',
    :'stats' => :'AgentStats',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/weft/generated/models/agent.rb', line 348

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      slug == o.slug &&
      wallet_address == o.wallet_address &&
      description == o.description &&
      category == o.category &&
      visibility == o.visibility &&
      verified == o.verified &&
      claimed == o.claimed &&
      stats == o.stats &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


366
367
368
# File 'lib/weft/generated/models/agent.rb', line 366

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



372
373
374
# File 'lib/weft/generated/models/agent.rb', line 372

def hash
  [id, name, slug, wallet_address, description, category, visibility, verified, claimed, stats, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/weft/generated/models/agent.rb', line 194

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @slug.nil?
    invalid_properties.push('invalid value for "slug", slug cannot be nil.')
  end

  if @wallet_address.nil?
    invalid_properties.push('invalid value for "wallet_address", wallet_address cannot be nil.')
  end

  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  if @visibility.nil?
    invalid_properties.push('invalid value for "visibility", visibility cannot be nil.')
  end

  if @verified.nil?
    invalid_properties.push('invalid value for "verified", verified cannot be nil.')
  end

  if @claimed.nil?
    invalid_properties.push('invalid value for "claimed", claimed cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/weft/generated/models/agent.rb', line 401

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/weft/generated/models/agent.rb', line 238

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @slug.nil?
  return false if @wallet_address.nil?
  return false if @category.nil?
  category_validator = EnumAttributeValidator.new('String', ["agent", "data_seller", "service_provider", "facilitator"])
  return false unless category_validator.valid?(@category)
  return false if @visibility.nil?
  visibility_validator = EnumAttributeValidator.new('String', ["public_profile", "private_profile", "unlisted"])
  return false unless visibility_validator.valid?(@visibility)
  return false if @verified.nil?
  return false if @claimed.nil?
  return false if @created_at.nil?
  true
end