Class: Weft::ResourceStats

Inherits:
ApiModelBase show all
Defined in:
lib/weft/generated/models/resource_stats.rb

Overview

Aggregate public payment stats for the resource.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ResourceStats

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/weft/generated/models/resource_stats.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::ResourceStats` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::ResourceStats`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'total_paid')
    self.total_paid = attributes[:'total_paid']
  else
    self.total_paid = nil
  end

  if attributes.key?(:'total_received')
    self.total_received = attributes[:'total_received']
  else
    self.total_received = nil
  end

  if attributes.key?(:'payments_made')
    self.payments_made = attributes[:'payments_made']
  else
    self.payments_made = nil
  end

  if attributes.key?(:'payments_received')
    self.payments_received = attributes[:'payments_received']
  else
    self.payments_received = nil
  end

  if attributes.key?(:'unique_counterparties')
    self.unique_counterparties = attributes[:'unique_counterparties']
  else
    self.unique_counterparties = nil
  end

  if attributes.key?(:'first_seen')
    self.first_seen = attributes[:'first_seen']
  else
    self.first_seen = nil
  end

  if attributes.key?(:'last_active')
    self.last_active = attributes[:'last_active']
  else
    self.last_active = nil
  end
end

Instance Attribute Details

#first_seenObject

Returns the value of attribute first_seen.



31
32
33
# File 'lib/weft/generated/models/resource_stats.rb', line 31

def first_seen
  @first_seen
end

#last_activeObject

Returns the value of attribute last_active.



33
34
35
# File 'lib/weft/generated/models/resource_stats.rb', line 33

def last_active
  @last_active
end

#payments_madeObject

Returns the value of attribute payments_made.



25
26
27
# File 'lib/weft/generated/models/resource_stats.rb', line 25

def payments_made
  @payments_made
end

#payments_receivedObject

Returns the value of attribute payments_received.



27
28
29
# File 'lib/weft/generated/models/resource_stats.rb', line 27

def payments_received
  @payments_received
end

#total_paidObject

Total atomic units paid out by this resource.



20
21
22
# File 'lib/weft/generated/models/resource_stats.rb', line 20

def total_paid
  @total_paid
end

#total_receivedObject

Total atomic units received by this resource.



23
24
25
# File 'lib/weft/generated/models/resource_stats.rb', line 23

def total_received
  @total_received
end

#unique_counterpartiesObject

Returns the value of attribute unique_counterparties.



29
30
31
# File 'lib/weft/generated/models/resource_stats.rb', line 29

def unique_counterparties
  @unique_counterparties
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/weft/generated/models/resource_stats.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/weft/generated/models/resource_stats.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/weft/generated/models/resource_stats.rb', line 36

def self.attribute_map
  {
    :'total_paid' => :'total_paid',
    :'total_received' => :'total_received',
    :'payments_made' => :'payments_made',
    :'payments_received' => :'payments_received',
    :'unique_counterparties' => :'unique_counterparties',
    :'first_seen' => :'first_seen',
    :'last_active' => :'last_active'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/weft/generated/models/resource_stats.rb', line 285

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/weft/generated/models/resource_stats.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
# File 'lib/weft/generated/models/resource_stats.rb', line 59

def self.openapi_types
  {
    :'total_paid' => :'Integer',
    :'total_received' => :'Integer',
    :'payments_made' => :'Integer',
    :'payments_received' => :'Integer',
    :'unique_counterparties' => :'Integer',
    :'first_seen' => :'Time',
    :'last_active' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



258
259
260
261
262
263
264
265
266
267
268
# File 'lib/weft/generated/models/resource_stats.rb', line 258

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      total_paid == o.total_paid &&
      total_received == o.total_received &&
      payments_made == o.payments_made &&
      payments_received == o.payments_received &&
      unique_counterparties == o.unique_counterparties &&
      first_seen == o.first_seen &&
      last_active == o.last_active
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


272
273
274
# File 'lib/weft/generated/models/resource_stats.rb', line 272

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



278
279
280
# File 'lib/weft/generated/models/resource_stats.rb', line 278

def hash
  [total_paid, total_received, payments_made, payments_received, unique_counterparties, first_seen, last_active].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/weft/generated/models/resource_stats.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @total_paid.nil?
    invalid_properties.push('invalid value for "total_paid", total_paid cannot be nil.')
  end

  if @total_received.nil?
    invalid_properties.push('invalid value for "total_received", total_received cannot be nil.')
  end

  if @payments_made.nil?
    invalid_properties.push('invalid value for "payments_made", payments_made cannot be nil.')
  end

  if @payments_received.nil?
    invalid_properties.push('invalid value for "payments_received", payments_received cannot be nil.')
  end

  if @unique_counterparties.nil?
    invalid_properties.push('invalid value for "unique_counterparties", unique_counterparties cannot be nil.')
  end

  if @first_seen.nil?
    invalid_properties.push('invalid value for "first_seen", first_seen cannot be nil.')
  end

  if @last_active.nil?
    invalid_properties.push('invalid value for "last_active", last_active cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/weft/generated/models/resource_stats.rb', line 307

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
180
181
182
183
184
# File 'lib/weft/generated/models/resource_stats.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @total_paid.nil?
  return false if @total_received.nil?
  return false if @payments_made.nil?
  return false if @payments_received.nil?
  return false if @unique_counterparties.nil?
  return false if @first_seen.nil?
  return false if @last_active.nil?
  true
end