Class: Weft::SearchAccessMethod
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Weft::SearchAccessMethod
- Defined in:
- lib/weft/generated/models/search_access_method.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_method_id ⇒ Object
Returns the value of attribute access_method_id.
-
#asset ⇒ Object
Returns the value of attribute asset.
-
#asset_decimals ⇒ Object
Returns the value of attribute asset_decimals.
-
#merchant ⇒ Object
Returns the value of attribute merchant.
-
#network ⇒ Object
Returns the value of attribute network.
-
#price ⇒ Object
Returns the value of attribute price.
-
#protocol ⇒ Object
Returns the value of attribute protocol.
-
#scheme ⇒ Object
Returns the value of attribute scheme.
-
#status ⇒ Object
Returns the value of attribute status.
-
#terms ⇒ Object
Returns the value of attribute terms.
-
#weft_fetch ⇒ Object
Returns the value of attribute weft_fetch.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SearchAccessMethod
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SearchAccessMethod
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/weft/generated/models/search_access_method.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::SearchAccessMethod` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::SearchAccessMethod`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'access_method_id') self.access_method_id = attributes[:'access_method_id'] else self.access_method_id = nil end if attributes.key?(:'protocol') self.protocol = attributes[:'protocol'] else self.protocol = nil end if attributes.key?(:'scheme') self.scheme = attributes[:'scheme'] end if attributes.key?(:'network') self.network = attributes[:'network'] end if attributes.key?(:'asset') self.asset = attributes[:'asset'] end if attributes.key?(:'asset_decimals') self.asset_decimals = attributes[:'asset_decimals'] end if attributes.key?(:'price') self.price = attributes[:'price'] else self.price = nil end if attributes.key?(:'merchant') self.merchant = attributes[:'merchant'] end if attributes.key?(:'terms') self.terms = attributes[:'terms'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'weft_fetch') self.weft_fetch = attributes[:'weft_fetch'] else self.weft_fetch = nil end end |
Instance Attribute Details
#access_method_id ⇒ Object
Returns the value of attribute access_method_id.
18 19 20 |
# File 'lib/weft/generated/models/search_access_method.rb', line 18 def access_method_id @access_method_id end |
#asset ⇒ Object
Returns the value of attribute asset.
26 27 28 |
# File 'lib/weft/generated/models/search_access_method.rb', line 26 def asset @asset end |
#asset_decimals ⇒ Object
Returns the value of attribute asset_decimals.
28 29 30 |
# File 'lib/weft/generated/models/search_access_method.rb', line 28 def asset_decimals @asset_decimals end |
#merchant ⇒ Object
Returns the value of attribute merchant.
32 33 34 |
# File 'lib/weft/generated/models/search_access_method.rb', line 32 def merchant @merchant end |
#network ⇒ Object
Returns the value of attribute network.
24 25 26 |
# File 'lib/weft/generated/models/search_access_method.rb', line 24 def network @network end |
#price ⇒ Object
Returns the value of attribute price.
30 31 32 |
# File 'lib/weft/generated/models/search_access_method.rb', line 30 def price @price end |
#protocol ⇒ Object
Returns the value of attribute protocol.
20 21 22 |
# File 'lib/weft/generated/models/search_access_method.rb', line 20 def protocol @protocol end |
#scheme ⇒ Object
Returns the value of attribute scheme.
22 23 24 |
# File 'lib/weft/generated/models/search_access_method.rb', line 22 def scheme @scheme end |
#status ⇒ Object
Returns the value of attribute status.
36 37 38 |
# File 'lib/weft/generated/models/search_access_method.rb', line 36 def status @status end |
#terms ⇒ Object
Returns the value of attribute terms.
34 35 36 |
# File 'lib/weft/generated/models/search_access_method.rb', line 34 def terms @terms end |
#weft_fetch ⇒ Object
Returns the value of attribute weft_fetch.
38 39 40 |
# File 'lib/weft/generated/models/search_access_method.rb', line 38 def weft_fetch @weft_fetch end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/weft/generated/models/search_access_method.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/weft/generated/models/search_access_method.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/weft/generated/models/search_access_method.rb', line 63 def self.attribute_map { :'access_method_id' => :'access_method_id', :'protocol' => :'protocol', :'scheme' => :'scheme', :'network' => :'network', :'asset' => :'asset', :'asset_decimals' => :'asset_decimals', :'price' => :'price', :'merchant' => :'merchant', :'terms' => :'terms', :'status' => :'status', :'weft_fetch' => :'weft_fetch' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/weft/generated/models/search_access_method.rb', line 303 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 |
# File 'lib/weft/generated/models/search_access_method.rb', line 107 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/weft/generated/models/search_access_method.rb', line 90 def self.openapi_types { :'access_method_id' => :'String', :'protocol' => :'String', :'scheme' => :'String', :'network' => :'String', :'asset' => :'String', :'asset_decimals' => :'Integer', :'price' => :'Object', :'merchant' => :'Object', :'terms' => :'Object', :'status' => :'String', :'weft_fetch' => :'SearchWeftFetchCompatibility' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/weft/generated/models/search_access_method.rb', line 272 def ==(o) return true if self.equal?(o) self.class == o.class && access_method_id == o.access_method_id && protocol == o.protocol && scheme == o.scheme && network == o.network && asset == o.asset && asset_decimals == o.asset_decimals && price == o.price && merchant == o.merchant && terms == o.terms && status == o.status && weft_fetch == o.weft_fetch end |
#eql?(o) ⇒ Boolean
290 291 292 |
# File 'lib/weft/generated/models/search_access_method.rb', line 290 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
296 297 298 |
# File 'lib/weft/generated/models/search_access_method.rb', line 296 def hash [access_method_id, protocol, scheme, network, asset, asset_decimals, price, merchant, terms, status, weft_fetch].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/weft/generated/models/search_access_method.rb', line 183 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @access_method_id.nil? invalid_properties.push('invalid value for "access_method_id", access_method_id cannot be nil.') end if @protocol.nil? invalid_properties.push('invalid value for "protocol", protocol cannot be nil.') end if @price.nil? invalid_properties.push('invalid value for "price", price cannot be nil.') end if @weft_fetch.nil? invalid_properties.push('invalid value for "weft_fetch", weft_fetch cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/weft/generated/models/search_access_method.rb', line 325 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/weft/generated/models/search_access_method.rb', line 207 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @access_method_id.nil? return false if @protocol.nil? protocol_validator = EnumAttributeValidator.new('String', ["x402", "mpp", "free"]) return false unless protocol_validator.valid?(@protocol) return false if @price.nil? status_validator = EnumAttributeValidator.new('String', ["listed", "observed", "unavailable"]) return false unless status_validator.valid?(@status) return false if @weft_fetch.nil? true end |