Class: Weft::SearchAgentCard
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Weft::SearchAgentCard
- Defined in:
- lib/weft/generated/models/search_agent_card.rb
Overview
A2A-spec-shaped AgentCard. Free-form ‘capabilities` and per-skill metadata follow the upstream A2A schema; documented here only at the surface level Weft’s index actually populates.
Instance Attribute Summary collapse
-
#capabilities ⇒ Object
Returns the value of attribute capabilities.
-
#default_input_modes ⇒ Object
Returns the value of attribute default_input_modes.
-
#default_output_modes ⇒ Object
Returns the value of attribute default_output_modes.
-
#description ⇒ Object
Returns the value of attribute description.
-
#name ⇒ Object
Returns the value of attribute name.
-
#protocol_version ⇒ Object
Returns the value of attribute protocol_version.
-
#skills ⇒ Object
Returns the value of attribute skills.
-
#url ⇒ Object
Returns the value of attribute url.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SearchAgentCard
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SearchAgentCard
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::SearchAgentCard` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::SearchAgentCard`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'protocol_version') self.protocol_version = attributes[:'protocol_version'] end if attributes.key?(:'capabilities') if (value = attributes[:'capabilities']).is_a?(Hash) self.capabilities = value end end if attributes.key?(:'default_input_modes') if (value = attributes[:'default_input_modes']).is_a?(Array) self.default_input_modes = value end end if attributes.key?(:'default_output_modes') if (value = attributes[:'default_output_modes']).is_a?(Array) self.default_output_modes = value end end if attributes.key?(:'skills') if (value = attributes[:'skills']).is_a?(Array) self.skills = value end end end |
Instance Attribute Details
#capabilities ⇒ Object
Returns the value of attribute capabilities.
29 30 31 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 29 def capabilities @capabilities end |
#default_input_modes ⇒ Object
Returns the value of attribute default_input_modes.
31 32 33 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 31 def default_input_modes @default_input_modes end |
#default_output_modes ⇒ Object
Returns the value of attribute default_output_modes.
33 34 35 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 33 def default_output_modes @default_output_modes end |
#description ⇒ Object
Returns the value of attribute description.
21 22 23 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 21 def description @description end |
#name ⇒ Object
Returns the value of attribute name.
19 20 21 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 19 def name @name end |
#protocol_version ⇒ Object
Returns the value of attribute protocol_version.
27 28 29 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 27 def protocol_version @protocol_version end |
#skills ⇒ Object
Returns the value of attribute skills.
35 36 37 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 35 def skills @skills end |
#url ⇒ Object
Returns the value of attribute url.
23 24 25 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 23 def url @url end |
#version ⇒ Object
Returns the value of attribute version.
25 26 27 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 25 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 38 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'url' => :'url', :'version' => :'version', :'protocol_version' => :'protocolVersion', :'capabilities' => :'capabilities', :'default_input_modes' => :'defaultInputModes', :'default_output_modes' => :'defaultOutputModes', :'skills' => :'skills' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 190 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 63 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'url' => :'String', :'version' => :'String', :'protocol_version' => :'String', :'capabilities' => :'Hash<String, Object>', :'default_input_modes' => :'Array<String>', :'default_output_modes' => :'Array<String>', :'skills' => :'Array<SearchSkill>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && url == o.url && version == o.version && protocol_version == o.protocol_version && capabilities == o.capabilities && default_input_modes == o.default_input_modes && default_output_modes == o.default_output_modes && skills == o.skills end |
#eql?(o) ⇒ Boolean
177 178 179 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 177 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 183 def hash [name, description, url, version, protocol_version, capabilities, default_input_modes, default_output_modes, skills].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 |
# File 'lib/weft/generated/models/search_agent_card.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |