Class: Weft::SearchPricing
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Weft::SearchPricing
- Defined in:
- lib/weft/generated/models/search_pricing.rb
Overview
Aggregate pricing at the agent level. ‘recipient_address` is intentionally absent from the index — under x402 it is delivered per-request in the `402 Payment Required` challenge from the agent.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount_usd ⇒ Object
Default per-call amount; individual skills may override via ‘price_usd`.
-
#network ⇒ Object
Settlement network (e.g. ‘base-sepolia`).
-
#protocol ⇒ Object
Returns the value of attribute protocol.
-
#scheme ⇒ Object
Returns the value of attribute scheme.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SearchPricing
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SearchPricing
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/weft/generated/models/search_pricing.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::SearchPricing` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::SearchPricing`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'protocol') self.protocol = attributes[:'protocol'] end if attributes.key?(:'scheme') self.scheme = attributes[:'scheme'] end if attributes.key?(:'amount_usd') self.amount_usd = attributes[:'amount_usd'] end if attributes.key?(:'network') self.network = attributes[:'network'] end end |
Instance Attribute Details
#amount_usd ⇒ Object
Default per-call amount; individual skills may override via ‘price_usd`.
24 25 26 |
# File 'lib/weft/generated/models/search_pricing.rb', line 24 def amount_usd @amount_usd end |
#network ⇒ Object
Settlement network (e.g. ‘base-sepolia`).
27 28 29 |
# File 'lib/weft/generated/models/search_pricing.rb', line 27 def network @network end |
#protocol ⇒ Object
Returns the value of attribute protocol.
19 20 21 |
# File 'lib/weft/generated/models/search_pricing.rb', line 19 def protocol @protocol end |
#scheme ⇒ Object
Returns the value of attribute scheme.
21 22 23 |
# File 'lib/weft/generated/models/search_pricing.rb', line 21 def scheme @scheme end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/weft/generated/models/search_pricing.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/weft/generated/models/search_pricing.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 |
# File 'lib/weft/generated/models/search_pricing.rb', line 52 def self.attribute_map { :'protocol' => :'protocol', :'scheme' => :'scheme', :'amount_usd' => :'amount_usd', :'network' => :'network' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/weft/generated/models/search_pricing.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/weft/generated/models/search_pricing.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 |
# File 'lib/weft/generated/models/search_pricing.rb', line 72 def self.openapi_types { :'protocol' => :'String', :'scheme' => :'String', :'amount_usd' => :'String', :'network' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 |
# File 'lib/weft/generated/models/search_pricing.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && protocol == o.protocol && scheme == o.scheme && amount_usd == o.amount_usd && network == o.network end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/weft/generated/models/search_pricing.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/weft/generated/models/search_pricing.rb', line 187 def hash [protocol, scheme, amount_usd, network].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
122 123 124 125 126 127 128 129 130 131 |
# File 'lib/weft/generated/models/search_pricing.rb', line 122 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+(\.\d{1,6})?$/) if !@amount_usd.nil? && @amount_usd !~ pattern invalid_properties.push("invalid value for \"amount_usd\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/weft/generated/models/search_pricing.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
135 136 137 138 139 140 141 |
# File 'lib/weft/generated/models/search_pricing.rb', line 135 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' protocol_validator = EnumAttributeValidator.new('String', ["x402", "mpp", "free"]) return false unless protocol_validator.valid?(@protocol) return false if !@amount_usd.nil? && @amount_usd !~ Regexp.new(/^\d+(\.\d{1,6})?$/) true end |