Class: Weft::SearchResult

Inherits:
ApiModelBase show all
Defined in:
lib/weft/generated/models/search_result.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SearchResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/weft/generated/models/search_result.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::SearchResult` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::SearchResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  else
    self.score = nil
  end

  if attributes.key?(:'protocol')
    self.protocol = attributes[:'protocol']
  else
    self.protocol = nil
  end

  if attributes.key?(:'domain')
    if (value = attributes[:'domain']).is_a?(Array)
      self.domain = value
    end
  else
    self.domain = nil
  end

  if attributes.key?(:'reseller')
    self.reseller = attributes[:'reseller']
  end

  if attributes.key?(:'upstream')
    self.upstream = attributes[:'upstream']
  end

  if attributes.key?(:'agent_card')
    self.agent_card = attributes[:'agent_card']
  else
    self.agent_card = nil
  end

  if attributes.key?(:'pricing')
    self.pricing = attributes[:'pricing']
  else
    self.pricing = nil
  end

  if attributes.key?(:'ranking')
    self.ranking = attributes[:'ranking']
  else
    self.ranking = nil
  end

  if attributes.key?(:'endpoints')
    self.endpoints = attributes[:'endpoints']
  else
    self.endpoints = nil
  end
end

Instance Attribute Details

#agent_cardObject

Returns the value of attribute agent_card.



36
37
38
# File 'lib/weft/generated/models/search_result.rb', line 36

def agent_card
  @agent_card
end

#domainObject

Domain tags declared by the agent.



28
29
30
# File 'lib/weft/generated/models/search_result.rb', line 28

def domain
  @domain
end

#endpointsObject

Returns the value of attribute endpoints.



42
43
44
# File 'lib/weft/generated/models/search_result.rb', line 42

def endpoints
  @endpoints
end

#idObject

Stable agent identifier (e.g. ‘weft:agent:agentmail`).



19
20
21
# File 'lib/weft/generated/models/search_result.rb', line 19

def id
  @id
end

#pricingObject

Returns the value of attribute pricing.



38
39
40
# File 'lib/weft/generated/models/search_result.rb', line 38

def pricing
  @pricing
end

#protocolObject

Agent protocol surface.



25
26
27
# File 'lib/weft/generated/models/search_result.rb', line 25

def protocol
  @protocol
end

#rankingObject

Returns the value of attribute ranking.



40
41
42
# File 'lib/weft/generated/models/search_result.rb', line 40

def ranking
  @ranking
end

#resellerObject

Reseller slug if this agent is fronted by an aggregator (e.g. ‘locus`).



31
32
33
# File 'lib/weft/generated/models/search_result.rb', line 31

def reseller
  @reseller
end

#scoreObject

Cosine similarity score, clipped to [0, 1].



22
23
24
# File 'lib/weft/generated/models/search_result.rb', line 22

def score
  @score
end

#upstreamObject

Upstream provider hostname when fronted by a reseller.



34
35
36
# File 'lib/weft/generated/models/search_result.rb', line 34

def upstream
  @upstream
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/weft/generated/models/search_result.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/weft/generated/models/search_result.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/weft/generated/models/search_result.rb', line 67

def self.attribute_map
  {
    :'id' => :'id',
    :'score' => :'score',
    :'protocol' => :'protocol',
    :'domain' => :'domain',
    :'reseller' => :'reseller',
    :'upstream' => :'upstream',
    :'agent_card' => :'agent_card',
    :'pricing' => :'pricing',
    :'ranking' => :'ranking',
    :'endpoints' => :'endpoints'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/weft/generated/models/search_result.rb', line 376

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



109
110
111
112
# File 'lib/weft/generated/models/search_result.rb', line 109

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/weft/generated/models/search_result.rb', line 93

def self.openapi_types
  {
    :'id' => :'String',
    :'score' => :'Float',
    :'protocol' => :'String',
    :'domain' => :'Array<String>',
    :'reseller' => :'String',
    :'upstream' => :'String',
    :'agent_card' => :'SearchAgentCard',
    :'pricing' => :'SearchPricing',
    :'ranking' => :'SearchRanking',
    :'endpoints' => :'SearchEndpoints'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/weft/generated/models/search_result.rb', line 346

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      score == o.score &&
      protocol == o.protocol &&
      domain == o.domain &&
      reseller == o.reseller &&
      upstream == o.upstream &&
      agent_card == o.agent_card &&
      pricing == o.pricing &&
      ranking == o.ranking &&
      endpoints == o.endpoints
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


363
364
365
# File 'lib/weft/generated/models/search_result.rb', line 363

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



369
370
371
# File 'lib/weft/generated/models/search_result.rb', line 369

def hash
  [id, score, protocol, domain, reseller, upstream, agent_card, pricing, ranking, endpoints].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/weft/generated/models/search_result.rb', line 191

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @score.nil?
    invalid_properties.push('invalid value for "score", score cannot be nil.')
  end

  if @score > 1
    invalid_properties.push('invalid value for "score", must be smaller than or equal to 1.')
  end

  if @score < 0
    invalid_properties.push('invalid value for "score", must be greater than or equal to 0.')
  end

  if @protocol.nil?
    invalid_properties.push('invalid value for "protocol", protocol cannot be nil.')
  end

  if @domain.nil?
    invalid_properties.push('invalid value for "domain", domain cannot be nil.')
  end

  if @agent_card.nil?
    invalid_properties.push('invalid value for "agent_card", agent_card cannot be nil.')
  end

  if @pricing.nil?
    invalid_properties.push('invalid value for "pricing", pricing cannot be nil.')
  end

  if @ranking.nil?
    invalid_properties.push('invalid value for "ranking", ranking cannot be nil.')
  end

  if @endpoints.nil?
    invalid_properties.push('invalid value for "endpoints", endpoints cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/weft/generated/models/search_result.rb', line 398

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/weft/generated/models/search_result.rb', line 239

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @score.nil?
  return false if @score > 1
  return false if @score < 0
  return false if @protocol.nil?
  protocol_validator = EnumAttributeValidator.new('String', ["a2a", "mcp", "openapi"])
  return false unless protocol_validator.valid?(@protocol)
  return false if @domain.nil?
  return false if @agent_card.nil?
  return false if @pricing.nil?
  return false if @ranking.nil?
  return false if @endpoints.nil?
  true
end