Class: Weft::SearchSkill

Inherits:
ApiModelBase show all
Defined in:
lib/weft/generated/models/search_skill.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SearchSkill

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/weft/generated/models/search_skill.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::SearchSkill` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::SearchSkill`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'examples')
    if (value = attributes[:'examples']).is_a?(Array)
      self.examples = value
    end
  end

  if attributes.key?(:'input_modes')
    if (value = attributes[:'input_modes']).is_a?(Array)
      self.input_modes = value
    end
  end

  if attributes.key?(:'output_modes')
    if (value = attributes[:'output_modes']).is_a?(Array)
      self.output_modes = value
    end
  end

  if attributes.key?(:'streaming')
    self.streaming = attributes[:'streaming']
  end

  if attributes.key?(:'endpoint')
    self.endpoint = attributes[:'endpoint']
  end

  if attributes.key?(:'price_usd')
    self.price_usd = attributes[:'price_usd']
  end
end

Instance Attribute Details

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/weft/generated/models/search_skill.rb', line 22

def description
  @description
end

#endpointObject

Returns the value of attribute endpoint.



35
36
37
# File 'lib/weft/generated/models/search_skill.rb', line 35

def endpoint
  @endpoint
end

#examplesObject

Returns the value of attribute examples.



26
27
28
# File 'lib/weft/generated/models/search_skill.rb', line 26

def examples
  @examples
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/weft/generated/models/search_skill.rb', line 18

def id
  @id
end

#input_modesObject

Returns the value of attribute input_modes.



28
29
30
# File 'lib/weft/generated/models/search_skill.rb', line 28

def input_modes
  @input_modes
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/weft/generated/models/search_skill.rb', line 20

def name
  @name
end

#output_modesObject

Returns the value of attribute output_modes.



30
31
32
# File 'lib/weft/generated/models/search_skill.rb', line 30

def output_modes
  @output_modes
end

#price_usdObject

Per-call price in USD for this individual skill.



38
39
40
# File 'lib/weft/generated/models/search_skill.rb', line 38

def price_usd
  @price_usd
end

#streamingObject

True for skills that require streaming transport (e.g. websockets). Streaming skills are filtered out of results by default so non-streaming clients only see callable skills.



33
34
35
# File 'lib/weft/generated/models/search_skill.rb', line 33

def streaming
  @streaming
end

#tagsObject

Returns the value of attribute tags.



24
25
26
# File 'lib/weft/generated/models/search_skill.rb', line 24

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/weft/generated/models/search_skill.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/weft/generated/models/search_skill.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/weft/generated/models/search_skill.rb', line 41

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'tags' => :'tags',
    :'examples' => :'examples',
    :'input_modes' => :'inputModes',
    :'output_modes' => :'outputModes',
    :'streaming' => :'streaming',
    :'endpoint' => :'endpoint',
    :'price_usd' => :'price_usd'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/weft/generated/models/search_skill.rb', line 221

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/weft/generated/models/search_skill.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/weft/generated/models/search_skill.rb', line 67

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'tags' => :'Array<String>',
    :'examples' => :'Array<String>',
    :'input_modes' => :'Array<String>',
    :'output_modes' => :'Array<String>',
    :'streaming' => :'Boolean',
    :'endpoint' => :'SearchSkillEndpoint',
    :'price_usd' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/weft/generated/models/search_skill.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      tags == o.tags &&
      examples == o.examples &&
      input_modes == o.input_modes &&
      output_modes == o.output_modes &&
      streaming == o.streaming &&
      endpoint == o.endpoint &&
      price_usd == o.price_usd
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/weft/generated/models/search_skill.rb', line 208

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/weft/generated/models/search_skill.rb', line 214

def hash
  [id, name, description, tags, examples, input_modes, output_modes, streaming, endpoint, price_usd].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
160
161
162
163
164
# File 'lib/weft/generated/models/search_skill.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d+(\.\d{1,6})?$/)
  if !@price_usd.nil? && @price_usd !~ pattern
    invalid_properties.push("invalid value for \"price_usd\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/weft/generated/models/search_skill.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



168
169
170
171
172
# File 'lib/weft/generated/models/search_skill.rb', line 168

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@price_usd.nil? && @price_usd !~ Regexp.new(/^\d+(\.\d{1,6})?$/)
  true
end