Class: Weft::UserPrincipal
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Weft::UserPrincipal
- Defined in:
- lib/weft/generated/models/user_principal.rb
Overview
The buyer User represented by an account API key or OAuth token.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#buyer_enabled ⇒ Object
Returns the value of attribute buyer_enabled.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#email ⇒ Object
Returns the value of attribute email.
-
#id ⇒ Object
Returns the value of attribute id.
-
#principal_type ⇒ Object
Returns the value of attribute principal_type.
-
#provisioning_status ⇒ Object
Returns the value of attribute provisioning_status.
-
#seller_enabled ⇒ Object
Returns the value of attribute seller_enabled.
-
#status ⇒ Object
Returns the value of attribute status.
-
#wallet ⇒ Object
Returns the value of attribute wallet.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserPrincipal
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UserPrincipal
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/weft/generated/models/user_principal.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::UserPrincipal` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::UserPrincipal`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'principal_type') self.principal_type = attributes[:'principal_type'] else self.principal_type = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'buyer_enabled') self.buyer_enabled = attributes[:'buyer_enabled'] else self.buyer_enabled = nil end if attributes.key?(:'seller_enabled') self.seller_enabled = attributes[:'seller_enabled'] else self.seller_enabled = nil end if attributes.key?(:'provisioning_status') self.provisioning_status = attributes[:'provisioning_status'] else self.provisioning_status = nil end if attributes.key?(:'wallet') self.wallet = attributes[:'wallet'] else self.wallet = nil end end |
Instance Attribute Details
#buyer_enabled ⇒ Object
Returns the value of attribute buyer_enabled.
29 30 31 |
# File 'lib/weft/generated/models/user_principal.rb', line 29 def buyer_enabled @buyer_enabled end |
#display_name ⇒ Object
Returns the value of attribute display_name.
25 26 27 |
# File 'lib/weft/generated/models/user_principal.rb', line 25 def display_name @display_name end |
#email ⇒ Object
Returns the value of attribute email.
23 24 25 |
# File 'lib/weft/generated/models/user_principal.rb', line 23 def email @email end |
#id ⇒ Object
Returns the value of attribute id.
21 22 23 |
# File 'lib/weft/generated/models/user_principal.rb', line 21 def id @id end |
#principal_type ⇒ Object
Returns the value of attribute principal_type.
19 20 21 |
# File 'lib/weft/generated/models/user_principal.rb', line 19 def principal_type @principal_type end |
#provisioning_status ⇒ Object
Returns the value of attribute provisioning_status.
33 34 35 |
# File 'lib/weft/generated/models/user_principal.rb', line 33 def provisioning_status @provisioning_status end |
#seller_enabled ⇒ Object
Returns the value of attribute seller_enabled.
31 32 33 |
# File 'lib/weft/generated/models/user_principal.rb', line 31 def seller_enabled @seller_enabled end |
#status ⇒ Object
Returns the value of attribute status.
27 28 29 |
# File 'lib/weft/generated/models/user_principal.rb', line 27 def status @status end |
#wallet ⇒ Object
Returns the value of attribute wallet.
35 36 37 |
# File 'lib/weft/generated/models/user_principal.rb', line 35 def wallet @wallet end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/weft/generated/models/user_principal.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/weft/generated/models/user_principal.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/weft/generated/models/user_principal.rb', line 60 def self.attribute_map { :'principal_type' => :'principal_type', :'id' => :'id', :'email' => :'email', :'display_name' => :'display_name', :'status' => :'status', :'buyer_enabled' => :'buyer_enabled', :'seller_enabled' => :'seller_enabled', :'provisioning_status' => :'provisioning_status', :'wallet' => :'wallet' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/weft/generated/models/user_principal.rb', line 332 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 104 |
# File 'lib/weft/generated/models/user_principal.rb', line 100 def self.openapi_nullable Set.new([ :'wallet' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/weft/generated/models/user_principal.rb', line 85 def self.openapi_types { :'principal_type' => :'String', :'id' => :'Integer', :'email' => :'String', :'display_name' => :'String', :'status' => :'String', :'buyer_enabled' => :'Boolean', :'seller_enabled' => :'Boolean', :'provisioning_status' => :'String', :'wallet' => :'PrincipalWallet' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/weft/generated/models/user_principal.rb', line 303 def ==(o) return true if self.equal?(o) self.class == o.class && principal_type == o.principal_type && id == o.id && email == o.email && display_name == o.display_name && status == o.status && buyer_enabled == o.buyer_enabled && seller_enabled == o.seller_enabled && provisioning_status == o.provisioning_status && wallet == o.wallet end |
#eql?(o) ⇒ Boolean
319 320 321 |
# File 'lib/weft/generated/models/user_principal.rb', line 319 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
325 326 327 |
# File 'lib/weft/generated/models/user_principal.rb', line 325 def hash [principal_type, id, email, display_name, status, buyer_enabled, seller_enabled, provisioning_status, wallet].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/weft/generated/models/user_principal.rb', line 177 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @principal_type.nil? invalid_properties.push('invalid value for "principal_type", principal_type cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @buyer_enabled.nil? invalid_properties.push('invalid value for "buyer_enabled", buyer_enabled cannot be nil.') end if @seller_enabled.nil? invalid_properties.push('invalid value for "seller_enabled", seller_enabled cannot be nil.') end if @provisioning_status.nil? invalid_properties.push('invalid value for "provisioning_status", provisioning_status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/weft/generated/models/user_principal.rb', line 354 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/weft/generated/models/user_principal.rb', line 213 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @principal_type.nil? principal_type_validator = EnumAttributeValidator.new('String', ["user"]) return false unless principal_type_validator.valid?(@principal_type) return false if @id.nil? return false if @email.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["active", "blocked"]) return false unless status_validator.valid?(@status) return false if @buyer_enabled.nil? return false if @seller_enabled.nil? return false if @provisioning_status.nil? provisioning_status_validator = EnumAttributeValidator.new('String', ["pending", "ready", "not_applicable"]) return false unless provisioning_status_validator.valid?(@provisioning_status) true end |