Class: Weft::AccountDetails
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Weft::AccountDetails
- Defined in:
- lib/weft/generated/models/account_details.rb
Overview
The Organization that owns the authenticated API key — the principal in API v1 (the key represents an Org, not a person). api_key carries audit info about the key itself, including the user who minted it (created_by, which may be null if that user has left the Org).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#api_key ⇒ Object
Returns the value of attribute api_key.
-
#id ⇒ Object
Returns the value of attribute id.
-
#kind ⇒ Object
Returns the value of attribute kind.
-
#name ⇒ Object
Returns the value of attribute name.
-
#principal_type ⇒ Object
Returns the value of attribute principal_type.
-
#slug ⇒ Object
Returns the value of attribute slug.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AccountDetails
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/weft/generated/models/account_details.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::AccountDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::AccountDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'principal_type') self.principal_type = attributes[:'principal_type'] else self.principal_type = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'slug') self.slug = attributes[:'slug'] else self.slug = nil end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'api_key') self.api_key = attributes[:'api_key'] else self.api_key = nil end end |
Instance Attribute Details
#api_key ⇒ Object
Returns the value of attribute api_key.
29 30 31 |
# File 'lib/weft/generated/models/account_details.rb', line 29 def api_key @api_key end |
#id ⇒ Object
Returns the value of attribute id.
21 22 23 |
# File 'lib/weft/generated/models/account_details.rb', line 21 def id @id end |
#kind ⇒ Object
Returns the value of attribute kind.
27 28 29 |
# File 'lib/weft/generated/models/account_details.rb', line 27 def kind @kind end |
#name ⇒ Object
Returns the value of attribute name.
23 24 25 |
# File 'lib/weft/generated/models/account_details.rb', line 23 def name @name end |
#principal_type ⇒ Object
Returns the value of attribute principal_type.
19 20 21 |
# File 'lib/weft/generated/models/account_details.rb', line 19 def principal_type @principal_type end |
#slug ⇒ Object
Returns the value of attribute slug.
25 26 27 |
# File 'lib/weft/generated/models/account_details.rb', line 25 def slug @slug end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/weft/generated/models/account_details.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/weft/generated/models/account_details.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/weft/generated/models/account_details.rb', line 54 def self.attribute_map { :'principal_type' => :'principal_type', :'id' => :'id', :'name' => :'name', :'slug' => :'slug', :'kind' => :'kind', :'api_key' => :'api_key' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/weft/generated/models/account_details.rb', line 281 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/weft/generated/models/account_details.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 |
# File 'lib/weft/generated/models/account_details.rb', line 76 def self.openapi_types { :'principal_type' => :'String', :'id' => :'Integer', :'name' => :'String', :'slug' => :'String', :'kind' => :'String', :'api_key' => :'MeApiKey' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
255 256 257 258 259 260 261 262 263 264 |
# File 'lib/weft/generated/models/account_details.rb', line 255 def ==(o) return true if self.equal?(o) self.class == o.class && principal_type == o.principal_type && id == o.id && name == o.name && slug == o.slug && kind == o.kind && api_key == o.api_key end |
#eql?(o) ⇒ Boolean
268 269 270 |
# File 'lib/weft/generated/models/account_details.rb', line 268 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
274 275 276 |
# File 'lib/weft/generated/models/account_details.rb', line 274 def hash [principal_type, id, name, slug, kind, api_key].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/weft/generated/models/account_details.rb', line 148 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @principal_type.nil? invalid_properties.push('invalid value for "principal_type", principal_type cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @slug.nil? invalid_properties.push('invalid value for "slug", slug cannot be nil.') end if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @api_key.nil? invalid_properties.push('invalid value for "api_key", api_key cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/weft/generated/models/account_details.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/weft/generated/models/account_details.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @principal_type.nil? principal_type_validator = EnumAttributeValidator.new('String', ["organization"]) return false unless principal_type_validator.valid?(@principal_type) return false if @id.nil? return false if @name.nil? return false if @slug.nil? return false if @kind.nil? return false if @api_key.nil? true end |