Class: Weft::AccountDetails
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Weft::AccountDetails
- Defined in:
- lib/weft/generated/models/account_details.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#email ⇒ Object
Returns the value of attribute email.
-
#id ⇒ Object
Returns the value of attribute id.
-
#public_profile ⇒ Object
Returns the value of attribute public_profile.
-
#public_slug ⇒ Object
Returns the value of attribute public_slug.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AccountDetails
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/weft/generated/models/account_details.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::AccountDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::AccountDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'public_profile') self.public_profile = attributes[:'public_profile'] else self.public_profile = nil end if attributes.key?(:'public_slug') self.public_slug = attributes[:'public_slug'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
30 31 32 |
# File 'lib/weft/generated/models/account_details.rb', line 30 def created_at @created_at end |
#display_name ⇒ Object
Returns the value of attribute display_name.
24 25 26 |
# File 'lib/weft/generated/models/account_details.rb', line 24 def display_name @display_name end |
#email ⇒ Object
Returns the value of attribute email.
20 21 22 |
# File 'lib/weft/generated/models/account_details.rb', line 20 def email @email end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/weft/generated/models/account_details.rb', line 18 def id @id end |
#public_profile ⇒ Object
Returns the value of attribute public_profile.
26 27 28 |
# File 'lib/weft/generated/models/account_details.rb', line 26 def public_profile @public_profile end |
#public_slug ⇒ Object
Returns the value of attribute public_slug.
28 29 30 |
# File 'lib/weft/generated/models/account_details.rb', line 28 def public_slug @public_slug end |
#status ⇒ Object
Returns the value of attribute status.
22 23 24 |
# File 'lib/weft/generated/models/account_details.rb', line 22 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/weft/generated/models/account_details.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/weft/generated/models/account_details.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/weft/generated/models/account_details.rb', line 55 def self.attribute_map { :'id' => :'id', :'email' => :'email', :'status' => :'status', :'display_name' => :'display_name', :'public_profile' => :'public_profile', :'public_slug' => :'public_slug', :'created_at' => :'created_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/weft/generated/models/account_details.rb', line 272 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/weft/generated/models/account_details.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/weft/generated/models/account_details.rb', line 78 def self.openapi_types { :'id' => :'Integer', :'email' => :'String', :'status' => :'String', :'display_name' => :'String', :'public_profile' => :'Boolean', :'public_slug' => :'String', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/weft/generated/models/account_details.rb', line 245 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && email == o.email && status == o.status && display_name == o.display_name && public_profile == o.public_profile && public_slug == o.public_slug && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
259 260 261 |
# File 'lib/weft/generated/models/account_details.rb', line 259 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
265 266 267 |
# File 'lib/weft/generated/models/account_details.rb', line 265 def hash [id, email, status, display_name, public_profile, public_slug, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/weft/generated/models/account_details.rb', line 153 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @public_profile.nil? invalid_properties.push('invalid value for "public_profile", public_profile cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/weft/generated/models/account_details.rb', line 294 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/weft/generated/models/account_details.rb', line 181 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @email.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["active", "blocked"]) return false unless status_validator.valid?(@status) return false if @public_profile.nil? return false if @created_at.nil? true end |