Class: Weft::FetchRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Weft::FetchRequest
- Defined in:
- lib/weft/generated/models/fetch_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#body ⇒ Object
Returns the value of attribute body.
-
#headers ⇒ Object
Headers forwarded to the upstream.
-
#max_cost_usd ⇒ Object
Hard ceiling on what the buyer is willing to pay.
-
#method ⇒ Object
HTTP method to use against the upstream.
-
#url ⇒ Object
Target URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FetchRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FetchRequest
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/weft/generated/models/fetch_request.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::FetchRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::FetchRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'max_cost_usd') self.max_cost_usd = attributes[:'max_cost_usd'] else self.max_cost_usd = '0.10' end if attributes.key?(:'method') self.method = attributes[:'method'] else self.method = 'GET' end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'headers') if (value = attributes[:'headers']).is_a?(Hash) self.headers = value end end end |
Instance Attribute Details
#body ⇒ Object
Returns the value of attribute body.
27 28 29 |
# File 'lib/weft/generated/models/fetch_request.rb', line 27 def body @body end |
#headers ⇒ Object
Headers forwarded to the upstream. Up to 32 headers, 4 KB total. The following are silently stripped: ‘host`, `authorization`, `cookie`, `proxy-authorization`, `x-forwarded-*`, `x-real-ip`, `x-payment`, `connection`, `upgrade`.
30 31 32 |
# File 'lib/weft/generated/models/fetch_request.rb', line 30 def headers @headers end |
#max_cost_usd ⇒ Object
Hard ceiling on what the buyer is willing to pay. Defaults to ‘0.10` USD.
22 23 24 |
# File 'lib/weft/generated/models/fetch_request.rb', line 22 def max_cost_usd @max_cost_usd end |
#method ⇒ Object
HTTP method to use against the upstream.
25 26 27 |
# File 'lib/weft/generated/models/fetch_request.rb', line 25 def method @method end |
#url ⇒ Object
Target URL. Must pass Weft’s URL safety check (no SSRF / private IP ranges).
19 20 21 |
# File 'lib/weft/generated/models/fetch_request.rb', line 19 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/weft/generated/models/fetch_request.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/weft/generated/models/fetch_request.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 |
# File 'lib/weft/generated/models/fetch_request.rb', line 55 def self.attribute_map { :'url' => :'url', :'max_cost_usd' => :'max_cost_usd', :'method' => :'method', :'body' => :'body', :'headers' => :'headers' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/weft/generated/models/fetch_request.rb', line 228 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 91 |
# File 'lib/weft/generated/models/fetch_request.rb', line 87 def self.openapi_nullable Set.new([ :'body', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 |
# File 'lib/weft/generated/models/fetch_request.rb', line 76 def self.openapi_types { :'url' => :'String', :'max_cost_usd' => :'String', :'method' => :'String', :'body' => :'FetchRequestBody', :'headers' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 |
# File 'lib/weft/generated/models/fetch_request.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && url == o.url && max_cost_usd == o.max_cost_usd && method == o.method && body == o.body && headers == o.headers end |
#eql?(o) ⇒ Boolean
215 216 217 |
# File 'lib/weft/generated/models/fetch_request.rb', line 215 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
221 222 223 |
# File 'lib/weft/generated/models/fetch_request.rb', line 221 def hash [url, max_cost_usd, method, body, headers].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/weft/generated/models/fetch_request.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end pattern = Regexp.new(/^\d+(\.\d{1,6})?$/) if !@max_cost_usd.nil? && @max_cost_usd !~ pattern invalid_properties.push("invalid value for \"max_cost_usd\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/weft/generated/models/fetch_request.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 163 164 |
# File 'lib/weft/generated/models/fetch_request.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @url.nil? return false if !@max_cost_usd.nil? && @max_cost_usd !~ Regexp.new(/^\d+(\.\d{1,6})?$/) method_validator = EnumAttributeValidator.new('String', ["GET", "POST", "PUT", "PATCH", "DELETE"]) return false unless method_validator.valid?(@method) true end |