Class: Weft::FetchResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Weft::FetchResponse
- Defined in:
- lib/weft/generated/models/fetch_response.rb
Overview
Successful fetch envelope. ‘body_base64` is the upstream artifact bytes, base64-encoded. `paid_usd`, `tx_hash`, and `merchant` are populated only when the upstream charged for the response.
Instance Attribute Summary collapse
-
#artifact_id ⇒ Object
Internal artifact identifier if the response was persisted.
-
#body_base64 ⇒ Object
Base64-encoded response body.
-
#headers ⇒ Object
Response headers from the upstream.
-
#merchant ⇒ Object
Merchant reputation snapshot.
-
#paid_usd ⇒ Object
USD amount actually settled.
-
#status ⇒ Object
HTTP status returned by the upstream after the paid replay.
-
#tx_hash ⇒ Object
Settlement transaction hash.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FetchResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FetchResponse
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/weft/generated/models/fetch_response.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::FetchResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::FetchResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'headers') if (value = attributes[:'headers']).is_a?(Hash) self.headers = value end else self.headers = nil end if attributes.key?(:'body_base64') self.body_base64 = attributes[:'body_base64'] else self.body_base64 = nil end if attributes.key?(:'paid_usd') self.paid_usd = attributes[:'paid_usd'] else self.paid_usd = nil end if attributes.key?(:'tx_hash') self.tx_hash = attributes[:'tx_hash'] else self.tx_hash = nil end if attributes.key?(:'artifact_id') self.artifact_id = attributes[:'artifact_id'] else self.artifact_id = nil end if attributes.key?(:'merchant') self.merchant = attributes[:'merchant'] else self.merchant = nil end end |
Instance Attribute Details
#artifact_id ⇒ Object
Internal artifact identifier if the response was persisted.
35 36 37 |
# File 'lib/weft/generated/models/fetch_response.rb', line 35 def artifact_id @artifact_id end |
#body_base64 ⇒ Object
Base64-encoded response body. Empty string for empty bodies.
26 27 28 |
# File 'lib/weft/generated/models/fetch_response.rb', line 26 def body_base64 @body_base64 end |
#headers ⇒ Object
Response headers from the upstream.
23 24 25 |
# File 'lib/weft/generated/models/fetch_response.rb', line 23 def headers @headers end |
#merchant ⇒ Object
Merchant reputation snapshot. Null for free upstreams.
38 39 40 |
# File 'lib/weft/generated/models/fetch_response.rb', line 38 def merchant @merchant end |
#paid_usd ⇒ Object
USD amount actually settled. Null for free upstreams.
29 30 31 |
# File 'lib/weft/generated/models/fetch_response.rb', line 29 def paid_usd @paid_usd end |
#status ⇒ Object
HTTP status returned by the upstream after the paid replay.
20 21 22 |
# File 'lib/weft/generated/models/fetch_response.rb', line 20 def status @status end |
#tx_hash ⇒ Object
Settlement transaction hash. Null for free upstreams.
32 33 34 |
# File 'lib/weft/generated/models/fetch_response.rb', line 32 def tx_hash @tx_hash end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/weft/generated/models/fetch_response.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/weft/generated/models/fetch_response.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/weft/generated/models/fetch_response.rb', line 41 def self.attribute_map { :'status' => :'status', :'headers' => :'headers', :'body_base64' => :'body_base64', :'paid_usd' => :'paid_usd', :'tx_hash' => :'tx_hash', :'artifact_id' => :'artifact_id', :'merchant' => :'merchant' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/weft/generated/models/fetch_response.rb', line 292 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/weft/generated/models/fetch_response.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/weft/generated/models/fetch_response.rb', line 64 def self.openapi_types { :'status' => :'Integer', :'headers' => :'Hash<String, String>', :'body_base64' => :'String', :'paid_usd' => :'String', :'tx_hash' => :'String', :'artifact_id' => :'String', :'merchant' => :'Merchant' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/weft/generated/models/fetch_response.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && headers == o.headers && body_base64 == o.body_base64 && paid_usd == o.paid_usd && tx_hash == o.tx_hash && artifact_id == o.artifact_id && merchant == o.merchant end |
#eql?(o) ⇒ Boolean
279 280 281 |
# File 'lib/weft/generated/models/fetch_response.rb', line 279 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/weft/generated/models/fetch_response.rb', line 285 def hash [status, headers, body_base64, paid_usd, tx_hash, artifact_id, merchant].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/weft/generated/models/fetch_response.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @headers.nil? invalid_properties.push('invalid value for "headers", headers cannot be nil.') end if @body_base64.nil? invalid_properties.push('invalid value for "body_base64", body_base64 cannot be nil.') end if @paid_usd.nil? invalid_properties.push('invalid value for "paid_usd", paid_usd cannot be nil.') end if @tx_hash.nil? invalid_properties.push('invalid value for "tx_hash", tx_hash cannot be nil.') end if @artifact_id.nil? invalid_properties.push('invalid value for "artifact_id", artifact_id cannot be nil.') end if @merchant.nil? invalid_properties.push('invalid value for "merchant", merchant cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/weft/generated/models/fetch_response.rb', line 314 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/weft/generated/models/fetch_response.rb', line 181 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @status.nil? return false if @headers.nil? return false if @body_base64.nil? return false if @paid_usd.nil? return false if @tx_hash.nil? return false if @artifact_id.nil? return false if @merchant.nil? true end |