Class: Weft::SearchResponse

Inherits:
ApiModelBase show all
Defined in:
lib/weft/generated/models/search_response.rb

Overview

Spec-11 search envelope. ‘paid_usd`, `tx_hash`, and `artifact_id` are reserved for a later release that adds per-call billing and artifact persistence; they are always `null` in v1. `_mock: true` is set only by the mock backend.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SearchResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/weft/generated/models/search_response.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Weft::SearchResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Weft::SearchResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'results')
    if (value = attributes[:'results']).is_a?(Array)
      self.results = value
    end
  else
    self.results = nil
  end

  if attributes.key?(:'paid_usd')
    self.paid_usd = attributes[:'paid_usd']
  end

  if attributes.key?(:'tx_hash')
    self.tx_hash = attributes[:'tx_hash']
  end

  if attributes.key?(:'artifact_id')
    self.artifact_id = attributes[:'artifact_id']
  end

  if attributes.key?(:'_mock')
    self._mock = attributes[:'_mock']
  end
end

Instance Attribute Details

#_mockObject

Present and ‘true` only when served by the mock backend.



31
32
33
# File 'lib/weft/generated/models/search_response.rb', line 31

def _mock
  @_mock
end

#artifact_idObject

Always ‘null` in v1.



28
29
30
# File 'lib/weft/generated/models/search_response.rb', line 28

def artifact_id
  @artifact_id
end

Always ‘null` in v1.



22
23
24
# File 'lib/weft/generated/models/search_response.rb', line 22

def paid_usd
  @paid_usd
end

#resultsObject

Returns the value of attribute results.



19
20
21
# File 'lib/weft/generated/models/search_response.rb', line 19

def results
  @results
end

#tx_hashObject

Always ‘null` in v1.



25
26
27
# File 'lib/weft/generated/models/search_response.rb', line 25

def tx_hash
  @tx_hash
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/weft/generated/models/search_response.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/weft/generated/models/search_response.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/weft/generated/models/search_response.rb', line 34

def self.attribute_map
  {
    :'results' => :'results',
    :'paid_usd' => :'paid_usd',
    :'tx_hash' => :'tx_hash',
    :'artifact_id' => :'artifact_id',
    :'_mock' => :'_mock'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/weft/generated/models/search_response.rb', line 169

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/weft/generated/models/search_response.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/weft/generated/models/search_response.rb', line 55

def self.openapi_types
  {
    :'results' => :'Array<SearchResult>',
    :'paid_usd' => :'String',
    :'tx_hash' => :'String',
    :'artifact_id' => :'String',
    :'_mock' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



144
145
146
147
148
149
150
151
152
# File 'lib/weft/generated/models/search_response.rb', line 144

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      results == o.results &&
      paid_usd == o.paid_usd &&
      tx_hash == o.tx_hash &&
      artifact_id == o.artifact_id &&
      _mock == o._mock
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/weft/generated/models/search_response.rb', line 156

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



162
163
164
# File 'lib/weft/generated/models/search_response.rb', line 162

def hash
  [results, paid_usd, tx_hash, artifact_id, _mock].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



114
115
116
117
118
119
120
121
122
# File 'lib/weft/generated/models/search_response.rb', line 114

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @results.nil?
    invalid_properties.push('invalid value for "results", results cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/weft/generated/models/search_response.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



126
127
128
129
130
# File 'lib/weft/generated/models/search_response.rb', line 126

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @results.nil?
  true
end